@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.02.
 package Dancer2::Plugin::LogReport;
 use vars '$VERSION';
-$VERSION = '1.12';
+$VERSION = '1.14';
 
 
 use warnings;
@@ -84,9 +84,22 @@ on_plugin_import
     # the specific error to a generic error, when displayed to the user.
     # The message can be customised in the config file.
     my $fatal_error_message = $settings->{fatal_error_message}
-        || "An unexpected error has occurred";
+       // "An unexpected error has occurred";
+
     unless($dsl->app->config->{show_errors})
-    {   $hide_real_message->{$_} = $fatal_error_message for qw/FAULT ALERT FAILURE PANIC/;
+    {   $hide_real_message->{$_} = $fatal_error_message
+            for qw/FAULT ALERT FAILURE PANIC/;
+    }
+
+    if(my $forward_template = $settings->{forward_template})
+    {   # Add a route for the specified template
+        $dsl->app->add_route
+          ( method => 'get'
+          , regexp => qr!^/\Q$forward_template\E$!,
+          , code   => sub { shift->app->template($forward_template) }
+          );
+        # Forward to that new route
+        $settings->{forward_url} = $forward_template;
     }
 
     # This is so that all messages go into the session, to be displayed
@@ -94,6 +107,13 @@ on_plugin_import
     dispatcher CALLBACK => 'error_handler'
       , callback => \&_error_handler
       , mode     => 'DEBUG';
+
+    Log::Report::Dispatcher->addSkipStack( sub { $_[0][0] =~
+        m/ ^ Dancer2\:\:(?:Plugin|Logger)\:\:LogReport
+         | ^ Dancer2\:\:Core\:\:Role\:\:DSL
+         /x
+    });
+
 };    # ";" required!
 
 
@@ -112,7 +132,7 @@ sub _message_add($)
 
     return
         if ! $session_messages{$msg->reason}
-        ||   $msg->inClass('no_session');
+        || $msg->inClass('no_session');
 
     my $app = $_dsl->app;
     unless($app->request)
@@ -147,9 +167,24 @@ sub _error_handler($$$$)
 {   my ($disp, $options, $reason, $message) = @_;
 
     my $fatal_handler = sub {
-        my $req = $_dsl->request;
-        _forward_home( $_dsl, $_[0] )
-            if $req && ($req->uri ne '/' || !$req->is_get);
+
+        # Check whether this fatal message has been caught, in which case we
+        # don't want to redirect
+        return _message_add($_[0])
+            if exists $options->{is_fatal} && !$options->{is_fatal};
+
+        my $req = $_dsl->request
+            or return;
+
+        # Don't forward if it's a GET request to the error page, as it will
+        # cause a recursive loop. In this case, do nothing, and let dancer
+        # handle it.
+        # return not needed because of Return::MultiLevel hack, but let's
+        # leave it in anyway in hope.
+        return _forward_home($_dsl, $_[0])
+            if $req->uri ne $_settings->{forward_url} || !$req->is_get;
+
+        return;
     };
 
     $message->reason($reason);
@@ -162,24 +197,11 @@ sub _error_handler($$$$)
         # This could have already been caught by the process
         # subroutine, in which case we should continue running
         # of the program. In all other cases, we should bail
-        # out. With the former, the exception will have been
-        # re-thrown as a non-fatal exception, so check that.
-      , ERROR   => sub {
-            return _message_add( $_[0] )
-                if exists $options->{is_fatal} && !$options->{is_fatal};
-
-            my $req = $_dsl->request;
-            return  _forward_home( $_dsl, $_[0] )
-                if $req && ($req->uri ne '/' || !$req->is_get);
-
-            return;
-       }
+        # out.
+      , ERROR   => $fatal_handler
 
         # 'FAULT', 'ALERT', 'FAILURE', 'PANIC'
-        # All these are fatal errors. Display error to user, but
-        # forward home so that we can reload. However, don't if
-        # it's a GET request to the home, as it will cause a recursive
-        # loop. In this case, do nothing, and let dancer handle it.
+        # All these are fatal errors.
       , FAULT   => $fatal_handler
       , ALERT   => $fatal_handler
       , FAILURE => $fatal_handler
