@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Domain;
 use vars '$VERSION';
-$VERSION = '1.12';
+$VERSION = '1.14';
 
 use base 'Log::Report::Minimal::Domain';
 
@@ -45,7 +45,7 @@ sub configure(%)
     $self->SUPER::configure(%args);
 
     my $transl = $args{translator} || Log::Report::Translator->new;
-    $transl    =  Log::Report::Translator->new(@$transl)
+    $transl    =  Log::Report::Translator->new(%$transl)
         if ref $transl eq 'HASH';
 
     !blessed $transl || $transl->isa('Log::Report::Translator')
